
import json
import io


def write_json_file(content: str, file_path: str):
    with io.open(file_path, 'w', encoding='utf8') as outfile:
        outfile.write(content)

'''
Reference: 
https://stackoverflow.com/questions/12309269/how-do-i-write-json-data-to-a-file
'''



from fastapi import FastAPI
from fastapi.staticfiles import StaticFiles
import uvicorn


def start_api():
    app = FastAPI()
    app.mount("/", StaticFiles(directory="ui", html=True), name="static")
    uvicorn.run(app, host="0.0.0.0", port=8080)
    



from setuptools import setup, find_packages
from importlib.metadata import entry_points

CLASSIFIERS = [
    "Operating System :: OS Independent",
    "Programming Language :: Python :: 3.6",
    "Programming Language :: Python :: 3.7",
    "Programming Language :: Python :: 3.8",
    "Programming Language :: Python :: 3.9",
]

setup(name='tileset_analyzer',
      version='0.0.16',
      url='https://github.com/geoyogesh/tileset_analyzer',
      license='MIT',
      author='Yogesh Dhanapal',
      author_email='geoyogesh@gmail.com',
      entry_points={"console_scripts": ["tileset_analyzer = tileset_analyzer.main:cli"]},
      description='Analyze vector Tileset',
      python_requires=">=3.9, <4",
      packages=find_packages(),
      long_description=open('README.md').read(),
      long_description_content_type='text/markdown',
      zip_safe=False,
      classifiers=CLASSIFIERS,
      install_requires=["fastapi", "uvicorn[standard]"]
 )






from tileset_analyzer.api.main_api import start_api
from tileset_analyzer.data_source.tile_source_factory import TilesetSourceFactory
from tileset_analyzer.utils.json_utils import write_json_file
import sys

OUTPUT_JSON = 'ui/data/analysis_result.json'


def execute(src_path):
    print('processing started')

    data_source = TilesetSourceFactory.get_tileset_source(src_path)
    result = data_source.analyze()

    write_json_file(result.get_json(), OUTPUT_JSON)
    print('processing completed')

    print('Web UI started')
    start_api()
    print('Web UI stopped')



def cli():
    
    print('input:')
    print(sys.argv)
    print('------------------')
    src_path = None
    if '--source' in sys.argv[1:]:
        print(sys.argv)
        source_index = sys.argv.index('--source')
        src_path = sys.argv[source_index + 1]
    else:
        print('invalid Input.. Missing --source argument')
        exit(0)

    execute(src_path)



'''
if __name__ == "__main__":
   cli()
'''



import abc
from sqlite3 import Connection
from typing import List
from tileset_analyzer.entities.level_count import LevelCount
from tileset_analyzer.entities.tileset_analysis_result import TilesetAnalysisResult


class TileSource(abc.ABC):
    @abc.abstractmethod
    def __init__(self, src_path: str):
        pass

    @abc.abstractmethod
    def count_tiles(self) -> int:
        pass

    @abc.abstractmethod
    def count_tiles_by_z(self) -> List[LevelCount]:
        pass

    @abc.abstractmethod
    def analyze(self) -> TilesetAnalysisResult:
        pass
